import request from '@/utils/request'
import { parseStrEmpty } from "@/utils/goldenwater";

export function listDocCate(query) {
  return request({ url: '/slgc/docCate/list', method: 'get', params: query })
}

export function getDocCate(cateCode) {
  return request({ url: '/slgc/docCate/' + parseStrEmpty(cateCode), method: 'get' })
}

export function addDocCate(data) {
  return request({ url: '/slgc/docCate', method: 'post', data: data })
}

export function updateDocCate(data) {
  return request({ url: '/slgc/docCate', method: 'put', data: data })
}

export function delDocCate(cateCode) {
  return request({ url: '/slgc/docCate/' + cateCode, method: 'delete' })
}
